@@ -607,7 +607,7 @@ def _make_indexed_contiguous_file(filename):
 
 
 def _make_external_files():
-    """TODO."""
+    """Make netCDF files with external variables."""
 
     def _pp(
         filename,
@@ -616,7 +616,7 @@ def _make_external_files():
         combined=False,
         external_missing=False,
     ):
-        """TODO."""
+        """Make a netCDF file with some external variables."""
         nc = netCDF4.Dataset(filename, "w", format="NETCDF3_CLASSIC")
 
         nc.createDimension("grid_latitude", 10)
@@ -671,9 +671,9 @@ def _make_external_files():
             eastward_wind = nc.createVariable(
                 dimensions=("grid_latitude", "grid_longitude"),
                 datatype="f8",
-                varname=u"eastward_wind",
+                varname="eastward_wind",
             )
-            eastward_wind.coordinates = u"latitude longitude"
+            eastward_wind.coordinates = "latitude longitude"
             eastward_wind.standard_name = "eastward_wind"
             eastward_wind.cell_methods = (
                 "grid_longitude: mean (interval: 1 day comment: ok) "
@@ -716,7 +716,7 @@ def _make_external_files():
 
 
 def _make_gathered_file(filename):
-    """TODO."""
+    """Make a netCDF file with a gathered array."""
 
     def _jj(shape, list_values):
         array = numpy.ma.masked_all(shape)
